#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-web
version:              1.52.1
visibility:           public
id:                   hledger-web-1.52.1-IhyE7b4zTXSE1nLNmBSLeg
key:                  hledger-web-1.52.1-IhyE7b4zTXSE1nLNmBSLeg
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Web user interface for the hledger accounting system
description:
    A simple web user interface for the hledger accounting system,
    providing a more modern UI than the command-line or terminal interfaces.
    It can be used as a local single-user UI, or as a multi-user UI for
    viewing\/adding\/editing on the web.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance
abi:                  2dfa18fdd96c122bdd4920ab3cfe66ca
exposed:              True
exposed-modules:
    Hledger.Web Hledger.Web.App Hledger.Web.Application
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Main Hledger.Web.Settings
    Hledger.Web.Settings.StaticFiles Hledger.Web.Test
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common

hidden-modules:       Paths_hledger_web
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-web
hs-libraries:         HShledger-web-1.52.1-IhyE7b4zTXSE1nLNmBSLeg
depends:
    Decimal-0.5.2-Civ14aU7Mi2Ke3ya3hZ6tj
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG base-4.18.2.1
    base64-1.0-8olNGg1bM6MD5xgYFuEmIb
    blaze-html-0.9.2.0-npfK3H1ZuJH9Vz9ywDZve
    blaze-markup-0.8.3.0-BwtxwotQvqT6MBMEaH67IA bytestring-0.11.5.3
    case-insensitive-1.2.1.0-42CJmR7jfDI1QxR1AA3Hru
    clientsession-0.9.3.0-5efHbu5DFC7K0T4XpjIdhS
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    conduit-extra-1.3.8-Ck6pOXJmJPw7MIsaJ1VnN1 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    githash-0.1.7.0-Fg8yc7ROXwtL5yKInFIZ
    hjsmin-0.2.1-6GvkpzAYS9GDJki0difJKa
    hledger-1.52.1-5pElzc9euRS7vwJ6pteN2m
    hledger-lib-1.52.1-JTSlIeUWBQC4ql04zTz2TL
    hspec-2.11.7-DlmsZFIl5t8722t58ZW2or
    http-client-0.7.19-EUgGdw3KTvRKxRF4wbGFhk
    http-conduit-2.3.9.1-EhOu3SIoVgTGe8LjY9FuRl
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    megaparsec-9.7.1-3v9USGunK8PJV50Lxdl0PB mtl-2.3.1
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    safe-0.3.21-KdE8f1g6p6v53Pxmzg6oHI
    shakespeare-2.2.0-6aX5U9tFVlULMX2cpB9K4B template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-CVij6K5GN6q30I6j86A2Op
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    wai-3.2.4-DLXs1orvvdJGWv69GIPJL5
    wai-cors-0.2.7-BV9zlPasvJy7RAmEnxwcAm
    wai-extra-3.1.18-7yqfQMVgNQjGfrEO6Xo1jW
    wai-handler-launch-3.0.3.1-GlP7UIJ7SOsB40oA6ugnqf
    warp-3.4.0-E6ModISBE1f6pwNEXgw1VL
    yaml-0.11.11.2-AvIOnZYyDpQErZ41Aggoi5
    yesod-1.6.2.3-Id16T7052Ls7ITJn3zcgo1
    yesod-core-1.6.28.0-Ft208kyeYKA4xNwEDVz5uV
    yesod-form-1.7.9.3-RjMyBQpmRiHb2xOiw49Gs
    yesod-static-1.6.1.2-CfkCS4e4YB33nJ5anA9GU
    yesod-test-1.7.0.1-Be2bwRuTuMv6rvPtNAuOeD

haddock-interfaces:   /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html:         /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

